
**Eye Vision**
===========

Eye Vision provides a simple but powerful python library for Computer Vision. It uses
well know libraries libraries like OpenCv and Dask. Typical usage
often looks like this::

    import ziso
    from ziso import view
    
    file = ziso.read("image.jpg")
    view.rgb("image")
    
    ziso.zen

Speed
=========

Your favourite libraries compressed:

* OpenCV

* Matplotlib

* etc

Note:
-------------

Things to expect and know:

1. Easy implementation

2. Rapid Scalability

3. Portability

Read the Docs:-> Urls are https://eye-vision.readthedocs.io 
Eye-vision webpage:-> https://simbatmotsi.github.io/eye-vision/
Personal webpage:-> <http://bit.ly/simbatmotsi>